@@ -40,17 +40,11 @@ impl FixedBitSet
     
     /// Grow capacity to **bits**, all new bits initialized to zero
     pub fn grow(&mut self, bits: usize) {
-        let (mut cur_blocks, rem) = div_rem(self.length, BITS);
-        cur_blocks += (rem > 0) as usize;
-
         let (mut blocks, rem) = div_rem(bits, BITS);
         blocks += (rem > 0) as usize;
         if bits > self.length {
             self.length = bits;
-            self.data.reserve(blocks - cur_blocks);
-            for _ in 0..blocks - cur_blocks {
-                self.data.push(0);
-            }
+            self.data.resize(blocks, 0);
         }
     }
 
@@ -134,7 +128,6 @@ impl FixedBitSet
     #[inline]
     pub fn copy_bit(&mut self, from: usize, to: usize)
     {
-        assert!(from < self.length);
         assert!(to < self.length);
         let (to_block, t) = div_rem(to, BITS);
         let enabled = self.contains(from);
@@ -252,6 +245,8 @@ fn copy_bit() {
     assert!(fb.contains(1));
     fb.copy_bit(1, 42);
     assert!(fb.contains(42));
+    fb.copy_bit(1024, 42);
+    assert!(!fb[42]);
 }
 
 #[test]
